@@ -13,8 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.urls import reverse
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import messages
 from horizon import tables
@@ -87,11 +88,24 @@ class ResetReplicaStatus(tables.LinkAction):
 
 
 class DeleteReplica(tables.DeleteAction):
-    data_type_singular = _("Replica")
-    data_type_plural = _("Replicas")
-    action_past = _("Scheduled deletion of %(data_type)s")
     policy_rules = (("share_replica", "share_replica:delete"),)
 
+    @staticmethod
+    def action_present(count):
+        return ngettext_lazy(
+            u"Delete Replica",
+            u"Delete Replicas",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ngettext_lazy(
+            u"Deleted Replica",
+            u"Deleted Replicas",
+            count
+        )
+
     def get_policy_target(self, request, datum=None):
         return {"project_id": getattr(datum, "project_id", None)}
 
@@ -108,7 +122,7 @@ class DeleteReplica(tables.DeleteAction):
             replicas = manila.share_replica_list(request, replica.share_id)
             if share.replication_type is None:
                 return False
-            elif (share.replication_type is 'writable' and
+            elif (share.replication_type == 'writable' and
                   replica.status in DELETABLE_STATUSES and
                   len(replicas) > 1) or (
                       share.replication_type in ('dr', 'readable') and
