@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from horizon import tables
 
 from manila_ui.dashboards.project.user_messages import tables as project_tables
@@ -42,5 +42,8 @@ class UserMessagesAdminTable(project_tables.UserMessagesTable):
         row_actions = (
             DeleteUserMessage,
         )
-        columns = ('project_name', 'message_id', 'resource_type',
-                   'resource_id', 'user_message', 'created_at',)
+        columns = (
+            'project_name', 'message_id', 'message_level',
+            'resource_type',
+            'resource_id', 'user_message', 'created_at',
+        )
