@@ -237,10 +237,25 @@ class ManilaApiTests(base.APITestCase):
 
     def test_migration_cancel(self):
         api.migration_cancel(self.request, 'fake_share')
-
         self.manilaclient.shares.migration_cancel.assert_called_once_with(
             'fake_share')
 
+    @ddt.data(
+        ('name_updated_1', 'description_updated', True),
+        ('name_updated_2', 'description_updated', False),
+        ('name_updated_3', None, True),
+    )
+    @ddt.unpack
+    def test_share_type_update(
+            self, name, description, is_public):
+        api.share_type_update(self.request, self.id, name,
+                              description, is_public)
+
+        self.manilaclient.share_types.get.return_value.update.\
+            assert_called_once_with(name=name,
+                                    description=description,
+                                    is_public=is_public)
+
     def test_migration_get_progress(self):
         api.migration_get_progress(self.request, 'fake_share')
 
@@ -397,6 +412,7 @@ class ManilaApiTests(base.APITestCase):
             "description": None,
             "neutron_net_id": None,
             "neutron_subnet_id": None,
+            "availability_zone": None
         }
         expected_kwargs.update(**kwargs)
 
@@ -433,6 +449,26 @@ class ManilaApiTests(base.APITestCase):
         self.manilaclient.share_networks.delete.assert_called_once_with(
             share_network_id)
 
+    @ddt.data(
+        {"share_network_id": "some_network_id"},
+        {"share_network_id": "some_network_id",
+         "neutron_net_id": "some_neutron_net_id",
+         "neutron_subnet_id": "some_neutron_subnet_id",
+         "availability_zone": "some_availability_zone"},
+    )
+    def test_share_network_subnet_create(self, kwargs):
+        expected_kwargs = {
+            "share_network_id": None,
+            "neutron_net_id": None,
+            "neutron_subnet_id": None,
+            "availability_zone": None
+        }
+
+        expected_kwargs.update(**kwargs)
+        api.share_network_subnet_create(self.request, **kwargs)
+        self.manilaclient.share_network_subnets.create.assert_called_once_with(
+            **expected_kwargs)
+
     # Share server tests
 
     @ddt.data(
